@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import functools
 import itertools
+import string
 from collections import defaultdict
 
 from musictool import config
@@ -85,7 +86,6 @@ class Scale(NoteSet):
             self.notes_to_triad_root = {triad.notes: triad.root for triad in self.triads}
             self.notes_to_seventh_root = {seventh.notes: seventh.root for seventh in self.sevenths}
             self.notes_to_ninth_root = {ninth.notes: ninth.root for ninth in self.ninths}
-        self.html_classes += self.name,
 
     def _make_nths(self, ns: frozenset[int]) -> tuple[Chord, ...]:
         return tuple(
@@ -107,12 +107,14 @@ class Scale(NoteSet):
     def to_piano_image(self):
         return Piano(note_colors={note: config.scale_colors[scale] for note, scale in self.note_scales.items()})._repr_svg_()
 
-    def _repr_html_(self) -> str:
+    def _repr_html_(self, html_classes: tuple[str, ...] = ('card',)) -> str:
+        if self.name is not None:
+            html_classes += self.name,
         chords_hover = ''
         if C_name := self.note_scales.get(Note('C'), ''):
             C_name = f' | C {C_name}'
         return f"""
-        <div class='{' '.join(self.html_classes)}' {chords_hover}>
+        <div class='{' '.join(html_classes)}' {chords_hover}>
         <a href='{self.root.name}'><span class='card_header'><h3>{self.root.name} {self.name}{C_name}</h3></span></a>
         {self.to_piano_image()}
         </div>
@@ -137,14 +139,6 @@ class ComparedScales:
         self.del_notes = frozenset(left.notes) - frozenset(right.notes)
         if right.kind == 'diatonic':
             self.shared_triads = frozenset(left.triads) & frozenset(right.triads)
-        self.html_classes: tuple[str, ...] = ('card',)
-
-    def with_html_classes(self, classes: tuple[str, ...]) -> str:
-        prev = self.html_classes
-        self.html_classes = prev + classes
-        r = self._repr_html_()
-        self.html_classes = prev
-        return r
 
     # def __format__(self, format_spec): raise No
 
@@ -165,16 +159,33 @@ class ComparedScales:
         )._repr_svg_()
 
     # @functools.cached_property
-    def _repr_html_(self) -> str:
-        chords_hover = ''
+    def _repr_html_(
+        self,
+        html_classes: tuple[str, ...] = ('card',),
+        subtitle: str | None = None,
+    ) -> str:
         if C_name := self.right.note_scales.get(Note('C'), ''):
             C_name = f' | C {C_name}'
-        return f"""
-        <div class='{' '.join(self.html_classes)}' {chords_hover}>
-        <a href='{self.right.root.name}'><span class='card_header'><h3>{self.right.root.name} {self.right.name}{C_name}</h3></span></a>
-        {self.to_piano_image()}
+
+        mapping = dict(
+            classes=' '.join(html_classes),
+            href=self.right.root.name,
+            title=f'<h3>{self.right.root.name} {self.right.name}{C_name}</h3>',
+            subtitle=subtitle if subtitle is not None else '',
+            piano=self.to_piano_image(),
+        )
+
+        return string.Template("""\
+        <div class='$classes'>
+        <a href='$href'>
+            <div class='card_header'>
+                $title
+                $subtitle
+            </div>
+        </a>
+        $piano
         </div>
-        """
+        """).substitute(mapping)
 
     def __eq__(self, other): return self.key == other.key
     def __hash__(self): return hash(self.key)
